summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitem_imp.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
commit479f5f799523bffbcc83dff581a2299c047c6fff (patch)
tree186aae707ed02aac6c7cab2fb14e97f72aca5e36 /kjsembed/qtbindings/qcanvasitem_imp.cpp
parentf1dbff6145c98324ff82e34448b7483727e8ace4 (diff)
downloadtdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.tar.gz
tdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebindings@1157645 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitem_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasitem_imp.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/kjsembed/qtbindings/qcanvasitem_imp.cpp b/kjsembed/qtbindings/qcanvasitem_imp.cpp
index f2e1c0e0..c11b3780 100644
--- a/kjsembed/qtbindings/qcanvasitem_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasitem_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvasitem_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -66,15 +66,15 @@ void QCanvasItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
EnumValue enums[] = {
// enum RttiValues
- { "Rtti_Item", QCanvasItem::Rtti_Item },
- { "Rtti_Sprite", QCanvasItem::Rtti_Sprite },
- { "Rtti_PolygonalItem", QCanvasItem::Rtti_PolygonalItem },
- { "Rtti_Text", QCanvasItem::Rtti_Text },
- { "Rtti_Polygon", QCanvasItem::Rtti_Polygon },
- { "Rtti_Rectangle", QCanvasItem::Rtti_Rectangle },
- { "Rtti_Ellipse", QCanvasItem::Rtti_Ellipse },
- { "Rtti_Line", QCanvasItem::Rtti_Line },
- { "Rtti_Spline", QCanvasItem::Rtti_Spline },
+ { "Rtti_Item", TQCanvasItem::Rtti_Item },
+ { "Rtti_Sprite", TQCanvasItem::Rtti_Sprite },
+ { "Rtti_PolygonalItem", TQCanvasItem::Rtti_PolygonalItem },
+ { "Rtti_Text", TQCanvasItem::Rtti_Text },
+ { "Rtti_Polygon", TQCanvasItem::Rtti_Polygon },
+ { "Rtti_Rectangle", TQCanvasItem::Rtti_Rectangle },
+ { "Rtti_Ellipse", TQCanvasItem::Rtti_Ellipse },
+ { "Rtti_Line", TQCanvasItem::Rtti_Line },
+ { "Rtti_Spline", TQCanvasItem::Rtti_Spline },
{ 0, 0 }
};
@@ -135,7 +135,7 @@ void QCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -148,28 +148,28 @@ void QCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasItem pointer from an Object.
*/
-QCanvasItem *QCanvasItemImp::toQCanvasItem( KJS::Object &self )
+TQCanvasItem *QCanvasItemImp::toQCanvasItem( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasItem *>( obj );
+ return dynamic_cast<TQCanvasItem *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
/*
- if ( !op->inherits("QCanvasItem") ) {
+ if ( !op->inherits("TQCanvasItem") ) {
kdDebug() << "Typename of opaque canvas item is " << op->typeName() << endl;
// Check superclasses
return 0;
}
*/
- return op->toNative<QCanvasItem>();
+ return op->toNative<TQCanvasItem>();
}
/**
@@ -187,7 +187,7 @@ KJS::Object QCanvasItemImp::construct( KJS::ExecState *exec, const KJS::List &ar
break;
}
- QString msg = i18n("QCanvasItemCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasItemCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -197,15 +197,15 @@ KJS::Object QCanvasItemImp::QCanvasItem_1( KJS::ExecState *exec, const KJS::List
#if 0 // This constructor has been disabled by the XSL template
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the QCanvasItem object
+ // We should now create an instance of the TQCanvasItem object
- QCanvasItem *ret = new QCanvasItem(
+ TQCanvasItem *ret = new TQCanvasItem(
arg0 );
@@ -221,7 +221,7 @@ KJS::Value QCanvasItemImp::call( KJS::ExecState *exec, KJS::Object &self, const
/*
if ( !instance )
{
- QString msg = i18n( "QCanvasItemImp was not valid" );
+ TQString msg = i18n( "QCanvasItemImp was not valid" );
return throwError(exec, msg,KJS::ReferenceError);
}
*/
@@ -384,7 +384,7 @@ KJS::Value QCanvasItemImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- QString msg = i18n( "QCanvasItemImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasItemImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -565,10 +565,10 @@ KJS::Value QCanvasItemImp::advance_18( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QCanvasItemImp::collidesWith_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QCanvasItem *
return KJS::Value();
- const QCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -591,10 +591,10 @@ KJS::Value QCanvasItemImp::collisions_20( KJS::ExecState *exec, KJS::Object &obj
KJS::Value QCanvasItemImp::setCanvas_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter QCanvas *
return KJS::Value();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
instance->setCanvas(
arg0 );
@@ -605,7 +605,7 @@ KJS::Value QCanvasItemImp::setCanvas_21( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QCanvasItemImp::draw_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPainter arg0; // TODO (hack for qcanvas)
+ TQPainter arg0; // TODO (hack for qcanvas)
instance->draw(
arg0 );
@@ -756,7 +756,7 @@ KJS::Value QCanvasItemImp::rtti_37( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QCanvasItemImp::boundingRect_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QRect ret;
+ TQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
@@ -765,7 +765,7 @@ KJS::Value QCanvasItemImp::boundingRect_38( KJS::ExecState *exec, KJS::Object &o
KJS::Value QCanvasItemImp::boundingRectAdvanced_39( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QRect ret;
+ TQRect ret;
ret = instance->boundingRectAdvanced( );
return convertToValue( exec, ret );
@@ -776,7 +776,7 @@ KJS::Value QCanvasItemImp::canvas_40( KJS::ExecState *exec, KJS::Object &obj, co
{
instance->canvas( );
- return KJS::Value(); // Returns 'QCanvas *'
+ return KJS::Value(); // Returns 'TQCanvas *'
}
@@ -148,28 +148,28 @@ void QCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasItem pointer from an Object.
+ * Extract a TQCanvasItem pointer from an Object.
*/
@@ -197,15 +197,15 @@ KJS::Object QCanvasItemImp::QCanvasItem_1( KJS::ExecState *exec, const KJS::List
#if 0 // This constructor has been disabled by the XSL template
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
@@ -565,10 +565,10 @@ KJS::Value QCanvasItemImp::advance_18( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QCanvasItemImp::collidesWith_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();
@@ -591,10 +591,10 @@ KJS::Value QCanvasItemImp::collisions_20( KJS::ExecState *exec, KJS::Object &obj
KJS::Value QCanvasItemImp::setCanvas_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Value();